# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [v1.0.15](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.15) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.14...v1.0.15))

### Misc
- "2020-02-24 15:24 - Increased django-check-constraint version:VERSION = (1, 0, 14) to VERSION = (1, 0, 15)" ([2d13e70](https://github.com/jackton1/django-check-constraint/commit/2d13e70c0324e08e7ea0248d7cd39ef02714b8ae)).


## [v1.0.14](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.14) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.13...v1.0.14)) - 2020-02-24

### Added
- Added MANIFEST.in ([d19ea85](https://github.com/jackton1/django-check-constraint/commit/d19ea854e24ead87487f4f7395ee2f58c60216ce)).

### Misc
- "2020-02-24 15:23 - Increased django-check-constraint version:VERSION = (1, 0, 13) to VERSION = (1, 0, 14)" ([948eb4b](https://github.com/jackton1/django-check-constraint/commit/948eb4bccc6ad3e915c7f361142087c1fc25f3aa)).
- Updated CHANGELOG.md. ([b2006dc](https://github.com/jackton1/django-check-constraint/commit/b2006dc368a3e1167cd75668ca109840f7a58c8c)).


## [v1.0.13](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.13) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.12...v1.0.13)) - 2020-02-24

### Misc
- "2020-02-24 14:38 - Increased django-check-constraint version:VERSION = (1, 0, 12) to VERSION = (1, 0, 13)" ([3c1f894](https://github.com/jackton1/django-check-constraint/commit/3c1f89422fb799cb1554204e34902ea2175f899e)).
- Create FUNDING.yml ([4df4051](https://github.com/jackton1/django-check-constraint/commit/4df40510d3ac68cc4c1c0c4990758d60897ccbc9)).
- Update setup.py ([88c565f](https://github.com/jackton1/django-check-constraint/commit/88c565fb67d014768e1373378c822e6c0c81a474)).
- Updated CHANGELOG.md. ([9ee129a](https://github.com/jackton1/django-check-constraint/commit/9ee129ac3c1aa4d3100d4f59be1ef9b9ebf9e388)).


## [v1.0.12](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.12) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.11...v1.0.12)) - 2020-02-22

### Added
- Added caching. ([02bdda3](https://github.com/jackton1/django-check-constraint/commit/02bdda36a3fd6906e591f55a06d8717fbf97ba0d)).

### Fixed
- Fixed cache key. ([450a311](https://github.com/jackton1/django-check-constraint/commit/450a31121ad017870bec390986cf5f569685ee58)).
- Fixed cache key. ([8600eef](https://github.com/jackton1/django-check-constraint/commit/8600eefb16b0ec125ee5145a2609efdcd9e53b01)).
- Fixed lint errors. ([907b189](https://github.com/jackton1/django-check-constraint/commit/907b189878b5cac12c23f67ed978e701c4b380ef)).
- Fixed mysql test. ([1c80050](https://github.com/jackton1/django-check-constraint/commit/1c80050d3f06ff2cd2e6baa2520c97ed6fcca657)).
- Fixed test. ([54a6e8b](https://github.com/jackton1/django-check-constraint/commit/54a6e8b62b9e230a6aff07a0ac540fdae640130e)).
- Fixed test. ([c424f6f](https://github.com/jackton1/django-check-constraint/commit/c424f6f87c3a1aadd85375e3c6239dd547841729)).
- Fixed test. ([9c819ed](https://github.com/jackton1/django-check-constraint/commit/9c819edabd1072d5d8723f217473bdc9886d476c)).
- Fixed workflow. ([13999a6](https://github.com/jackton1/django-check-constraint/commit/13999a62f18bfe68c0c6f99af87666f36cee1d89)).
- Fixed workflow. ([4775435](https://github.com/jackton1/django-check-constraint/commit/477543560b5224d8e18496257b58ea5758abfadc)).

### Removed
- Remove cache skip. ([74a5b49](https://github.com/jackton1/django-check-constraint/commit/74a5b49c462b5648707e5137445979e8b3777e00)).

### Misc
- "2020-02-22 12:49 - Increased django-check-constraint version:VERSION = (1, 0, 11) to VERSION = (1, 0, 12)" ([1d3bc0c](https://github.com/jackton1/django-check-constraint/commit/1d3bc0cc613e1f860bef9f57deceee1a445dc47d)).
- Disabled sqlite test. ([49cf36e](https://github.com/jackton1/django-check-constraint/commit/49cf36e2b8fcb19aa207127fa204606506c49052)).
- Increased the test coverage. ([3affa6e](https://github.com/jackton1/django-check-constraint/commit/3affa6e064c8af16170d41a34a90d7926f2eeafa)).
- Speed up nox. ([75b940d](https://github.com/jackton1/django-check-constraint/commit/75b940dbbe13fd84200ecf371437b17a9c2a81c7)).
- Test revrting change. ([e4e6957](https://github.com/jackton1/django-check-constraint/commit/e4e6957676b56950ecaed74649d2716387ae15da)).
- Update README.md ([8655414](https://github.com/jackton1/django-check-constraint/commit/86554145c7e97d7977c31a49d801c5294198d202)).
- Update README.md ([cb3cc39](https://github.com/jackton1/django-check-constraint/commit/cb3cc3906b9eb348818aeb4ea4485cfb00df1af7)).
- Update README.md ([796a950](https://github.com/jackton1/django-check-constraint/commit/796a9507f0ae2861303af2cbf55199b9a2c5b5bd)).
- Update release to pypi target. ([f43b81a](https://github.com/jackton1/django-check-constraint/commit/f43b81abf4081e171c908b3dcd76ec36e06b87c1)).
- Updated CHANGELOG.md. ([3120935](https://github.com/jackton1/django-check-constraint/commit/31209353bc8c587fb6ccc9ca5fd927b7219a511c)).
- Updated README. ([e706ad4](https://github.com/jackton1/django-check-constraint/commit/e706ad47689a0aa879a21d7e704c680a22a34437)).


## [v1.0.11](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.11) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.10...v1.0.11)) - 2020-02-17

### Removed
- Removed push. ([ee3d4f2](https://github.com/jackton1/django-check-constraint/commit/ee3d4f21a8c40f92b724860e1c5ebbf945ff367f)).

### Misc
- "2020-02-16 19:46 - Increased django-check-constraint version:VERSION = (1, 0, 10) to VERSION = (1, 0, 11)" ([28d280b](https://github.com/jackton1/django-check-constraint/commit/28d280b29333ce229ed8298145cb8e93de299c74)).
- Updated CHANGELOG.md. ([83ef1a5](https://github.com/jackton1/django-check-constraint/commit/83ef1a51e69c83eb9e117544efc7b7ee24a982ae)).


## [v1.0.10](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.10) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.9...v1.0.10)) - 2020-02-17

### Fixed
- Fixed deployment. ([3f8eca9](https://github.com/jackton1/django-check-constraint/commit/3f8eca921b411905a06ed483838170b498284dbf)).

### Misc
- "2020-02-16 19:42 - Increased django-check-constraint version:VERSION = (1, 0, 9) to VERSION = (1, 0, 10)" ([1786987](https://github.com/jackton1/django-check-constraint/commit/1786987582e079fe6ca8a88f36b95d18bc229a7e)).
- Updated CHANGELOG.md. ([57a4179](https://github.com/jackton1/django-check-constraint/commit/57a4179f77fa4dcfc29e432e042894268f1ee9b8)).


## [v1.0.9](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.9) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.8...v1.0.9)) - 2020-02-17

### Removed
- Removed unused matrix ([23a05b7](https://github.com/jackton1/django-check-constraint/commit/23a05b7bb72e83b09c48e4af55a8f5287fd81c27)).

### Misc
- "2020-02-16 19:34 - Increased django-check-constraint version:VERSION = (1, 0, 8) to VERSION = (1, 0, 9)" ([846e90c](https://github.com/jackton1/django-check-constraint/commit/846e90cb2a578b7af408d367cff926d5fb6c9028)).
- Updated CHANGELOG.md. ([f6c9281](https://github.com/jackton1/django-check-constraint/commit/f6c92814cde33c3e1157794b9afaa7da416b8b3d)).
- Updated tags. ([90eb71a](https://github.com/jackton1/django-check-constraint/commit/90eb71a6f37f0502846a7b0dc9ae865506e1a57b)).


## [v1.0.8](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.8) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.7...v1.0.8)) - 2020-02-16

### Added
- Added a Personal Access token. ([3c45544](https://github.com/jackton1/django-check-constraint/commit/3c45544da73e05acc5c67f42009b3ab6aec9c078)).
- Added push to origins. ([ece5d2d](https://github.com/jackton1/django-check-constraint/commit/ece5d2d14699e6cd5de3605149920f160ecb33ec)).

### Misc
- "2020-02-16 18:38 - Increased django-check-constraint version:VERSION = (1, 0, 7) to VERSION = (1, 0, 8)" ([8fb4427](https://github.com/jackton1/django-check-constraint/commit/8fb442714709cfcc18cec3f6a79503e55fbdd5c1)).
- Updated CHANGELOG.md. ([48c6db7](https://github.com/jackton1/django-check-constraint/commit/48c6db76d18fbccf7d00167cb60c953a41cc330f)).
- Updated the types. ([3e0baa5](https://github.com/jackton1/django-check-constraint/commit/3e0baa560fd66e6ed2b475e8fb9d9cdaef0213b7)).


## [v1.0.7](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.7) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.5...v1.0.7)) - 2020-02-16

### Added
- Added echo command. ([cba6c42](https://github.com/jackton1/django-check-constraint/commit/cba6c42dbc1f3390a3e295495a1b71a57591cbe4)).

### Misc
- "2020-02-16 18:18 - Increased django-check-constraint version:VERSION = (1, 0, 6) to VERSION = (1, 0, 7)" ([8def0ec](https://github.com/jackton1/django-check-constraint/commit/8def0ecf1f8e805f8beb6482d7a0934162ab566f)).
- Cleaned Makefile. ([408e183](https://github.com/jackton1/django-check-constraint/commit/408e1833941be12d6123b5cd49783d18dea9fa90)).
- Updated CHANGELOG.md. ([3dc1f62](https://github.com/jackton1/django-check-constraint/commit/3dc1f62a28dd2f63798c2190eb5ff2e9529ece5b)).


## [v1.0.5](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.5) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.4...v1.0.5)) - 2020-02-16

### Removed
- Removed autoedit on ([8a5d4d6](https://github.com/jackton1/django-check-constraint/commit/8a5d4d68055e639d79af9fa66d88bf73a839ca35)).

### Misc
- "2020-02-16 18:09 - Increased django-check-constraint version:VERSION = (1, 0, 5) to VERSION = (1, 0, 6)" ([656f035](https://github.com/jackton1/django-check-constraint/commit/656f0355d97be7bd04900f3f0e85b2020ffeca45)).
- Updated CHANGELOG.md. ([51f939c](https://github.com/jackton1/django-check-constraint/commit/51f939c999209ecf9ef95cfeaf26a840ed227b3d)).


## [v1.0.4](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.4) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.3...v1.0.4)) - 2020-02-16

### Added
- Added the release workflow. ([e844bd9](https://github.com/jackton1/django-check-constraint/commit/e844bd917c6a3517e9e77432cda29b0d6ff906a8)).

### Fixed
- Fixed release script. ([f8d4062](https://github.com/jackton1/django-check-constraint/commit/f8d4062f40bed4aecd209576277fb8326d25cab1)).
- Fixed release script. ([ce9aeca](https://github.com/jackton1/django-check-constraint/commit/ce9aeca9a87bd29f0bcd22a8abca9c99546329c6)).
- Fixed release target. ([8bc7f03](https://github.com/jackton1/django-check-constraint/commit/8bc7f0363105c42224242926f3578b4ac9e21efb)).
- Fixed script. ([6ce55e7](https://github.com/jackton1/django-check-constraint/commit/6ce55e71e6af6932dc78589a8b9e59a1847a43ac)).
- Fixed script. ([38c9264](https://github.com/jackton1/django-check-constraint/commit/38c9264620f351087ec486344afd20460afe6d81)).
- Fixed script. ([36da8f7](https://github.com/jackton1/django-check-constraint/commit/36da8f7e842ea06d8be8c0bce3cc14368895ef87)).
- Fixed script. ([87c392c](https://github.com/jackton1/django-check-constraint/commit/87c392c5741db1ee016ac5f62b461745a3a97f73)).
- Fixed script. ([73b736f](https://github.com/jackton1/django-check-constraint/commit/73b736fe8a1ce0b4297ff43649656783d5c32f40)).

### Removed
- Removed push. ([fd0b48a](https://github.com/jackton1/django-check-constraint/commit/fd0b48a09226be41163db2e6253da992fe394d5b)).

### Misc
- "2020-02-16 12:37 - Increased django-check-constraint version:VERSION = (1, 0, 3) to VERSION = (1, 0, 4)" ([2878581](https://github.com/jackton1/django-check-constraint/commit/2878581ec5a34e774bff0c6b7ed9e39e6017c004)).
- "2020-02-16 17:31 - Increased django-check-constraint version:VERSION = (1, 0, 4) to VERSION = (1, 0, 5)" ([ad1a344](https://github.com/jackton1/django-check-constraint/commit/ad1a344f22847ef64d42e29defc3981fd9e299f7)).
- "2020-02-16 17:33 - Increased django-check-constraint version:VERSION = (1, 0, 5) to VERSION = (1, 0, 6)" ([51f2c5f](https://github.com/jackton1/django-check-constraint/commit/51f2c5fb047a2122fde8b27748401162d5f530ea)).
- "2020-02-16 17:36 - Increased django-check-constraint version:VERSION = (1, 0, 6) to VERSION = (1, 0, 7)" ([aa16f58](https://github.com/jackton1/django-check-constraint/commit/aa16f582c69b4988ecddc92eea49e54558d47cb9)).
- "2020-02-16 17:36 - Increased django-check-constraint version:VERSION = (1, 0, 7) to VERSION = (1, 0, 8)" ([f09ee96](https://github.com/jackton1/django-check-constraint/commit/f09ee96c6ab7fcea190f8e11fea2e5e10a32b279)).
- "2020-02-16 17:42 - Increased django-check-constraint version:VERSION = (1, 0, 3) to VERSION = (1, 0, 4)" ([1b01013](https://github.com/jackton1/django-check-constraint/commit/1b01013a2686d278828bc6b5cbc2928ac87488c3)).
- "2020-02-16 17:56 - Increased django-check-constraint version:VERSION = (1, 0, 4) to VERSION = (1, 0, 5)" ([0e5da3b](https://github.com/jackton1/django-check-constraint/commit/0e5da3bddba8e656eeed5d21dd9fdd0caf9cb975)).
- Create pythonpublish.yml ([3615eb9](https://github.com/jackton1/django-check-constraint/commit/3615eb90b999c773f998540bc7859c80a10568d0)).
- Revert changes to version. ([459f0fc](https://github.com/jackton1/django-check-constraint/commit/459f0fcca22560f9f68d36b0f5dc506b60d50151)).
- Revert version. ([c036b2d](https://github.com/jackton1/django-check-constraint/commit/c036b2d0c176adb14791ea2bcde17d425070314c)).
- Testing.. ([3623f00](https://github.com/jackton1/django-check-constraint/commit/3623f0055de31f2716faa921c07fab5ecaf1cf6a)).
- Update README.md ([54da74d](https://github.com/jackton1/django-check-constraint/commit/54da74d511c5a20ca79c5c9535fd4e2cd534a39e)).
- Update README.md ([99934e0](https://github.com/jackton1/django-check-constraint/commit/99934e080fb1af0bce48445941bb8ce61a5825e8)).
- Update script ([51194cc](https://github.com/jackton1/django-check-constraint/commit/51194cc29ac1f5187eba2fd9e15752a613edc200)).
- Update script ([4a9a57a](https://github.com/jackton1/django-check-constraint/commit/4a9a57a9b56176dfe9f7d6ad82802431ea6c4d36)).
- Updated CHANGELOG.md. ([b03ede1](https://github.com/jackton1/django-check-constraint/commit/b03ede145efb1fb471f241ea495fc4c6a935a4c4)).
- Updated CHANGELOG.md. ([c532485](https://github.com/jackton1/django-check-constraint/commit/c532485cdec07e10c10f62f2cb7afe7a778ec671)).
- Updated CHANGELOG.md. ([d60c7b4](https://github.com/jackton1/django-check-constraint/commit/d60c7b4173b13cd469d2393f1d87e5de905eb9c9)).
- Updated CHANGELOG.md. ([420f428](https://github.com/jackton1/django-check-constraint/commit/420f4285478fc01b1f85637a21d707613ac46f3a)).
- Updated CHANGELOG.md. ([d1b9920](https://github.com/jackton1/django-check-constraint/commit/d1b9920bd6b15d05d79d3df0b680fcd24f755783)).
- Updated CHANGELOG.md. ([2469605](https://github.com/jackton1/django-check-constraint/commit/246960587a776a34687784ebf6a92c2c62dc27ba)).
- Updated CHANGELOG.md. ([eb53457](https://github.com/jackton1/django-check-constraint/commit/eb534576e939ebeca5e0931286a406f61a608ade)).
- updated command. ([043078b](https://github.com/jackton1/django-check-constraint/commit/043078b1f8935e32dd725876f3e2cbedb37e8b8d)).
- updated command. ([2cccb9d](https://github.com/jackton1/django-check-constraint/commit/2cccb9d106f6aabb0d3f3a259553af0ccbf1b08b)).
- updated command. ([2ecbc81](https://github.com/jackton1/django-check-constraint/commit/2ecbc81544b813fdc2e0f13d41fb6fea5f1f7eaa)).
- updated command. ([7a2c520](https://github.com/jackton1/django-check-constraint/commit/7a2c52067ba0b6bcf5e91bae32be47f8292c15a5)).
- updated command. ([be2193e](https://github.com/jackton1/django-check-constraint/commit/be2193eced3b1d644f1ec87f661e5e65267e2a44)).
- Updated make targets. ([b63d762](https://github.com/jackton1/django-check-constraint/commit/b63d76254c42c77c4b350905c722b9c00714cadb)).
- Updated Makefile ([c97229f](https://github.com/jackton1/django-check-constraint/commit/c97229fbed8dcaaed44feb37d16a9c19219d5fc7)).
- Updated Makefile to include release trigger. ([024a2d6](https://github.com/jackton1/django-check-constraint/commit/024a2d62c256c13ca003e99fbfd7d4bd5b456a9e)).
- Updated script. ([3c9e2a2](https://github.com/jackton1/django-check-constraint/commit/3c9e2a2caa9096db561459d6471cdefab5145986)).
- Updated the deploy to pypi pipeline. ([283e9f3](https://github.com/jackton1/django-check-constraint/commit/283e9f31ce41eb385679f2451871ba53b434a326)).
- Updated the Makefile ([16da37f](https://github.com/jackton1/django-check-constraint/commit/16da37f7cb7f9c371c16323c9ef5a3c56038c5fd)).
- Updated the release script. ([f8c42b3](https://github.com/jackton1/django-check-constraint/commit/f8c42b31ad31c4b0037e3bb3c25895aac53d4811)).
- Updated the release to pypi step. ([fef3a0e](https://github.com/jackton1/django-check-constraint/commit/fef3a0e8c4189452a589ca61ecbd80d94b64d19c)).


## [v1.0.3](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.3) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.2...v1.0.3)) - 2020-02-16

### Misc
- "2020-02-16 10:21 - Increased django-check-constraint version:VERSION = (1, 0, 2) to VERSION = (1, 0, 3)" ([ac8659a](https://github.com/jackton1/django-check-constraint/commit/ac8659a09596acc32031cf95273b133a1afad314)).
- Create LICENSE ([9098cb8](https://github.com/jackton1/django-check-constraint/commit/9098cb87b6cb8aa7bf72103db1019a96aeb2680b)).
- Updated CHANGELOG.md. ([3a44872](https://github.com/jackton1/django-check-constraint/commit/3a44872dede80f87e63bda54e0e0a45f26bdbad7)).
- Updated README. ([5dedfe6](https://github.com/jackton1/django-check-constraint/commit/5dedfe66bae49c325c897ecc9c0f3b21fedcfff6)).
- Updated README. ([1906775](https://github.com/jackton1/django-check-constraint/commit/1906775bde33ba1215bc56960a8595448cd4618b)).
- Updated README. ([54eb92d](https://github.com/jackton1/django-check-constraint/commit/54eb92d388b19573dd302254a7115c9476a02aa9)).


## [v1.0.2](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.2) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.1...v1.0.2)) - 2020-02-16

### Misc
- "2020-02-16 09:55 - Increased django-check-constraint version:VERSION = (1, 0, 1) to VERSION = (1, 0, 2)" ([daad5f8](https://github.com/jackton1/django-check-constraint/commit/daad5f8dd5cf02c83481ba3e8802b2f64ae93f78)).
- Updated CHANGELOG.md. ([f337633](https://github.com/jackton1/django-check-constraint/commit/f3376335f27f601da95718685ffe083630737cc6)).
- Updated README. ([944c0e9](https://github.com/jackton1/django-check-constraint/commit/944c0e954dad15602baa8111bd13251713e501f3)).


## [v1.0.1](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.1) ([compare](https://github.com/jackton1/django-check-constraint/compare/v1.0.0...v1.0.1)) - 2020-02-16

### Fixed
- Fixed key words. ([8f0b51b](https://github.com/jackton1/django-check-constraint/commit/8f0b51b5445bcc5db6025cbec63d315a7e919554)).

### Misc
- "2020-02-16 09:46 - Increased django-check-constraint version:VERSION = (1, 0, 0) to VERSION = (2, 0, 0)" ([5f93d15](https://github.com/jackton1/django-check-constraint/commit/5f93d15c90897bf585d09219abcab48ee9e9029b)).
- "2020-02-16 09:49 - Increased django-check-constraint version:VERSION = (1, 0, 0) to VERSION = (1, 0, 1)" ([b7321ab](https://github.com/jackton1/django-check-constraint/commit/b7321ab755cd3031e62b5efc7f6173a1708d9ebe)).
- Updated bumpversion. ([296f6c9](https://github.com/jackton1/django-check-constraint/commit/296f6c997f7830c46632a50f8439da811419a34b)).
- Updated CHANGELOG.md. ([56b7b3b](https://github.com/jackton1/django-check-constraint/commit/56b7b3b0a9e3d0d37f0522fe2b6a1ffead57fd78)).
- Updated CHANGELOG.md. ([cedca48](https://github.com/jackton1/django-check-constraint/commit/cedca48561b5c3d703ab0493f644013168633e50)).


## [v1.0.0](https://github.com/jackton1/django-check-constraint/releases/tag/v1.0.0) ([compare](https://github.com/jackton1/django-check-constraint/compare/9680ca615965753725da4287b4dbcc7d8dd16063...v1.0.0)) - 2020-02-16

### Added
- Added .gitignore. ([f8166b4](https://github.com/jackton1/django-check-constraint/commit/f8166b477b98a50417f13c230f559ef0052f5442)).
- Added bumpversion config. ([a146df8](https://github.com/jackton1/django-check-constraint/commit/a146df8c0e024fc0f0cc65c1e034d69b1c124731)).
- Added bumpversion config. ([1880807](https://github.com/jackton1/django-check-constraint/commit/18808079d4bcb64f25cf0808893bb9de907e7456)).
- Added caching. ([bc4014b](https://github.com/jackton1/django-check-constraint/commit/bc4014ba7ca33e9bba136c6146503fbfab0cd903)).
- Added CHANGELOG.md ([0836550](https://github.com/jackton1/django-check-constraint/commit/08365504b6dc2092068fa66bad36208a52bb2cfc)).
- Added initial setup. ([3f12647](https://github.com/jackton1/django-check-constraint/commit/3f1264722e94623399e314bb9eaca8b68ac69639)).
- Added pre-commit hooks. ([6096b99](https://github.com/jackton1/django-check-constraint/commit/6096b99f3ae4ff7a8ce57b41c5449b2efb745c77)).
- Added sample usage. ([179989c](https://github.com/jackton1/django-check-constraint/commit/179989c835e471c32bd0867875b5f4daaee640d2)).
- Added support for multiple python versions. ([4f5a622](https://github.com/jackton1/django-check-constraint/commit/4f5a622c9857368934f7dde0242875acca0147c0)).

### Fixed
- fix bumpversion config. ([2e4569b](https://github.com/jackton1/django-check-constraint/commit/2e4569b313ed7d2cfd402c9193130c20a844644c)).
- fix bumpversion config. ([1b3309c](https://github.com/jackton1/django-check-constraint/commit/1b3309cde696a837e229d5473ad5b4b960290b9a)).
- Fixed cache key path. ([1f60cba](https://github.com/jackton1/django-check-constraint/commit/1f60cba96ee029941438d7c0e405b53d0eb645b0)).
- Fixed checkout. ([e0ceda7](https://github.com/jackton1/django-check-constraint/commit/e0ceda72ba4a688a178bd5d27c8a6784504d35af)).
- Fixed port. ([904bfaa](https://github.com/jackton1/django-check-constraint/commit/904bfaab0b135adba356d88dd7b03d5a88aa4042)).
- Fixed the test. ([092e2c0](https://github.com/jackton1/django-check-constraint/commit/092e2c04352cb59b7af6434378d80fb8a51a8239)).
- Fixed the workflow ([890bbb8](https://github.com/jackton1/django-check-constraint/commit/890bbb8e5da4fc11c1da2123c4ab62f617cecc51)).
- Fixed vulnerability. ([c31d30f](https://github.com/jackton1/django-check-constraint/commit/c31d30fcc59247298a6fbfb7c7f9e12f107fffdd)).
- Fixes test.. ([ad8d55d](https://github.com/jackton1/django-check-constraint/commit/ad8d55dafd6fd6b4b3da55ce421280cd8dc4f2fd)).

### Misc
- "2020-02-16 09:30 - Increased django-check-constraint version:VERSION = (0, 0, 1) to VERSION = (1, 0, 0)" ([a4114d6](https://github.com/jackton1/django-check-constraint/commit/a4114d6f0d3522694d01c47d9bb02cc4dc1d3988)).
- "2020-02-16 09:33 - Increased django-check-constraint version:VERSION = (0, 0, 1) to VERSION = (1, 0, 0)" ([00df6c2](https://github.com/jackton1/django-check-constraint/commit/00df6c20594a35e9dd4e6da425660cbeff5bed64)).
- "2020-02-16 09:43 - Increased django-check-constraint version:VERSION = (0, 0, 1) to VERSION = (1, 0, 0)" ([eca29a9](https://github.com/jackton1/django-check-constraint/commit/eca29a95f1253c23d46840d94d6a0026141838d3)).
- Bump django from 2.2 to 2.2.10 ([62e96d2](https://github.com/jackton1/django-check-constraint/commit/62e96d2371f0b37e4b3aeb07c0c30abc8b57193f)).
- Cleaned up the test. ([76a33d4](https://github.com/jackton1/django-check-constraint/commit/76a33d4687493f2eda334d03a6df3ea782962af0)).
- Downgraded mysql. ([33fd2b4](https://github.com/jackton1/django-check-constraint/commit/33fd2b4ee951158481485e2f98bb157748ecbc91)).
- Downgraded postgres. ([96b74fd](https://github.com/jackton1/django-check-constraint/commit/96b74fd04144311b6d33d9f31288bd088547bc69)).
- Initial commit ([9680ca6](https://github.com/jackton1/django-check-constraint/commit/9680ca615965753725da4287b4dbcc7d8dd16063)).
- Relax cached dir usage. ([40ef165](https://github.com/jackton1/django-check-constraint/commit/40ef165f5e19d293da3ba82d013b7433096113c9)).
- Reverted change to version. ([6bf41d8](https://github.com/jackton1/django-check-constraint/commit/6bf41d844cc0e7fa56b38f8bea9d714c2bb7a085)).
- Reverted change to version. ([93dd838](https://github.com/jackton1/django-check-constraint/commit/93dd838e66f97c0490ea8acaf7fa69351efc73c9)).
- Switched to use the cache ([4284b37](https://github.com/jackton1/django-check-constraint/commit/4284b37df5e2d2f95b0f1c72e0baf8a5dc71287f)).
- Updated black rev. ([373c85f](https://github.com/jackton1/django-check-constraint/commit/373c85f8f47ca4f354cf278f6021bbb1a6337cfc)).
- Updated CHANGELOG.md. ([8279329](https://github.com/jackton1/django-check-constraint/commit/82793290d6594c1a2b6c5e1d72cedce82de94e59)).
- Updated hook. ([14e6fe9](https://github.com/jackton1/django-check-constraint/commit/14e6fe91052a83132f33c24bcf04376eccfac261)).
- Updated README.md. ([c913067](https://github.com/jackton1/django-check-constraint/commit/c9130674a9cb9458e9d297f5fd400dc0c9a3b253)).
- Updated README.md. ([7b3e144](https://github.com/jackton1/django-check-constraint/commit/7b3e144c328ce87541455a48e8a2663867c46113)).
- Updated test command./ ([d785575](https://github.com/jackton1/django-check-constraint/commit/d78557553715b0bbce9c2fdde369a5401ed47483)).
- Updated the actions. ([1f358ed](https://github.com/jackton1/django-check-constraint/commit/1f358ed26f767f5d7f9e4994d9ac4d39b713cc3b)).
- Updated the actions. ([acd769e](https://github.com/jackton1/django-check-constraint/commit/acd769e1087d0d094f0e77a31c2af49a13c79a8c)).
- Updated the actions. ([96c2a28](https://github.com/jackton1/django-check-constraint/commit/96c2a282976dd7ec281e1a50f913c2ea8a26a25d)).
- Updated the port. ([366960e](https://github.com/jackton1/django-check-constraint/commit/366960e84cf536e83aac5837563bc0e4bce9da45)).
- Updated the postgresport. ([0e1c3aa](https://github.com/jackton1/django-check-constraint/commit/0e1c3aac0defc43c073639f521ff5cd285e1ed27)).
- Updated the skip msg. ([a9fe150](https://github.com/jackton1/django-check-constraint/commit/a9fe150de1760c9afc6440fad913c78e4b9f20df)).
- Updated the supported versions. ([ced09a1](https://github.com/jackton1/django-check-constraint/commit/ced09a13c63d7e23b8b91f168777a8f580436e1b)).
- Updated the test config. ([4591a27](https://github.com/jackton1/django-check-constraint/commit/4591a27c1fd4336416e95d3b0dedee2e3cd547f0)).
- Updated the test config. ([e5a26cc](https://github.com/jackton1/django-check-constraint/commit/e5a26cc8960e79a95d1d8cc89a17a575d18488cd)).
- Updated the url. ([b823eba](https://github.com/jackton1/django-check-constraint/commit/b823eba5c6b5fe3ed2f0d6812c6f5ecf1dd752c2)).
- Updated the version. ([44d066b](https://github.com/jackton1/django-check-constraint/commit/44d066b1ef30f8f50f5bdfaa344a76c982c92fb6)).
- Updated to include mysql-client.. ([42120e6](https://github.com/jackton1/django-check-constraint/commit/42120e6dfef9b07e35101938e2c08ac93c1936e6)).


